CorrStudy: Investigate the effect of correlated input parameters
Description
CorrStudy investigates the effect of correlated input parameters
Usage
CorrStudy(params, m = 1e+05, rho = seq(0.1, 0.9, by = 0.2), QMC = FALSE,
seed = 1)
Value
A matrix containing the results of the repeated simulations.
Arguments
params
named list containing numeric vectors Phi, Rho, Chi,
Ksi, M, G and A with the ranges for the input parameters.
m
numeric scalar containing the number of Monte Carlo
replications (for each correlation intensity). Defaults to 1e5.
rho
a numeric vector containing correlation intensities. Defaults to
seq(0.1,0.9,by=0.2).
QMC
logical scalar. If TRUE, an equidistant grid is
generated, if FALSE, uniformly distributed random numbers are
simulated.
seed
numeric scalar containing the random seed for each
simulation. Defaults to 1 in order to make results reproducible.
Details
CorrStudy performs repeated simulations via LEgame with
different values for the correlation intensity in order to illustrate
the effect of correlation on the deterrent effect of the legal exemption
system.