powered by
LEgame simulates the legal exemption game.
LEgame
LEgame(params, m = 1e+05, corrMat = diag(7), QMC = FALSE, seed = 1)
A dataframe containing the realized output of the simulation.
named list containing numeric vectors Phi, Rho, Chi, Ksi, M, G and A with the ranges for the input parameters.
numeric scalar containing the number of Monte Carlo replications. Defaults to 1e5.
1e5
matrix containing the correlation matrix for the simulation. Defaults to a 7x7 identity matrix.
logical scalar. If TRUE, an equidistant grid is generated, if FALSE, uniformly distributed random numbers are simulated.
TRUE
FALSE
numeric scalar containing the random seed for the simulation. Defaults to 1 in order to make results reproducible.
1
LEgame simulates the deterrent effect of the European cartel law based on a game-theoretic model for the legal exemption system.
Par <- list(Phi=c(0.1,0.5), Rho=c(0.5,0.9), Ksi=c(0.05,0.3), Chi=c(0.1,0.4), M=c(0.2,1.2), G=c(0.05,0.2), A=c(0.1,0.3)) res <- LEgame(params=Par, m=100000) print(aggResults(res))
Run the code above in your browser using DataLab