powered by
NoRglPlot visualizes the results of the simulation of the legal exemption system using 3D-projections and corresponding 3D-plots.
NoRglPlot
NoRglPlot(res, xvar = "rA", yvar = "rM", zvar = "c", xf = 1, yf = 1, zf = 1, pch = 16, phi = 20, theta = -30, d = 2)
Nothing useful, function called for its side effects.
dataframe containing results of simulation using LEgame.
LEgame
character scalar containing variable for the x-axis. Defaults to "rA", the simulated illegal gain.
"rA"
character scalar containing variable for the y-axis. Defaults to "rM", the simulated fine.
"rM"
character scalar containing variable for the z-axis. Defaults to "c", the complicance level.
"c"
numeric scalar containing scaling constant for the x-axis. Defaults to 1.
1
numeric scalar containing scaling constant for the y-axis. Defaults to 1.
numeric scalar containing scaling constant for the z-axis. Defaults to 1.
numeric or character scalar containing the plot character used for the individual points. Defaults to 16.
16
numeric scalar containing the phi angle (colatitude) for the perspective in degrees. Defaults to 20.
20
numeric scalar containing the theta angle (azimuthal direction) for the perspective in degrees. Defaults to -30.
-30
numeric scalar for the strenth of the perspective effect. Defaults to 2.
2
NoRglPlot visualizes the results of the simulation of the legal exemption system using 3D-projections and corresponding plots without using rgl/GL.
rgl
GL
# \donttest{ Par <- list(Phi=c(0.1,0.5), Rho=c(0.5,0.9), Ksi=c(0.05,0.3), Chi=c(0.1,0.4), M=c(0.2,1.2), G=c(0.05,0.2), A=c(0.1,0.3)) NoRglPlot(LEgame(params=Par, m=10000)) # }
Run the code above in your browser using DataLab