Learn R Programming

SimEUCartelLaw (version 1.0.4)

aggResults: Aggregate results of the legal exemption game simulation

Description

aggResults aggregates the results of LEgame.

Usage

aggResults(res)

Value

A matrix containing the aggregated results.

Arguments

res

dataframe containing results of simulation using LEgame.

Details

aggResults aggregates the results of LEgame to a matrix containing information about the fractions for the potential equilibria as well as the means and standard deviations of the error probabilities, the compliance level, and the expected illegal gains.

Examples

Run this code
Par <- list(Phi=c(0.1,0.5), Rho=c(0.5,0.9), Ksi=c(0.05,0.3), Chi=c(0.1,0.4),
            M=c(0.2,1.2), G=c(0.05,0.2), A=c(0.1,0.3))
res <- LEgame(params=Par, m=100000)
print(aggResults(res))

Run the code above in your browser using DataLab