aggResults: Aggregate results of the legal exemption game simulation
Description
aggResults aggregates the results of LEgame.
Usage
aggResults(res)
Value
A matrix containing the aggregated results.
Arguments
res
dataframe containing results of simulation using LEgame.
Details
aggResults aggregates the results of LEgame to a matrix
containing information about the fractions for the potential equilibria as
well as the means and standard deviations of the error probabilities, the
compliance level, and the expected illegal gains.